@@ -26,7 +26,7 @@
 
 /* 関数プロトタイプ */
 RData * check_target(OPArg *, VList *, SDir *);
-void overwrite_check(const OPArg *, const SDir *, CPInfo *, CPDD *);
+void check_overwrite(const OPArg *, const SDir *, CPInfo *, CPDD *);
 struct stat * make_directory(CPInfo *, CPDD *);
 static VList * dir_traverse(VList *, CPInfo *, OPArg *, SDir *, CPDD *);
 static inline void delete_last_slash(const int, char []);
@@ -67,7 +67,7 @@ static inline void set_same_or_different(const VList *, const char *, const char
 #define LINK_COPY \
 {\
 	count_link_plus(cpinfo, cpdd);\
-	overwrite_check(oparg, sdir, cpinfo, cpdd);\
+	check_overwrite(oparg, sdir, cpinfo, cpdd);\
 	file_list = append_list(file_list, (void *)cpinfo);\
 }
 
@@ -77,7 +77,7 @@ static inline void set_same_or_different(const VList *, const char *, const char
 	DRIVE_SAME_OR_DIFFERENT \
 \
 	{\
-		overwrite_check(oparg, sdir, cpinfo, cpdd);\
+		check_overwrite(oparg, sdir, cpinfo, cpdd);\
 	}\
 \
 	file_list = append_list(file_list, (void *)cpinfo);\
@@ -208,6 +208,7 @@ RData * check_target(OPArg *oparg, VList *drive_list, SDir *sdir)
 	/* 三項演算子 */
 	((loop_to - loop) == 1) ? (acount = SINGULAR) : (acount = PLURAL);
 
+	/* コピー元が.でコピー先が存在しないとき用の処理 */
 	switch(acount)
 	{
 	case SINGULAR:
@@ -215,7 +216,11 @@ RData * check_target(OPArg *oparg, VList *drive_list, SDir *sdir)
 			char *c = oparg->argv[loop];
 			if(
 				(c[0] == '.') &&
-				((c[1] == '\0') || ((c[1] == G_DIR_SEPARATOR) && (c[2] == '\0')))
+					(
+						(c[1] == '\0') ||
+						((c[1] == G_DIR_SEPARATOR) && (c[2] == '\0')) ||
+						((c[1] == G_DIR_SEPARATOR) && (c[2] == '.') && (c[3] == '\0'))
+					)
 			)
 			{
 				errno = 0;
@@ -538,7 +543,7 @@ static char *this_dir;
 
 /*******************************************************************************
 *******************************************************************************/
-void overwrite_check(const OPArg *oparg, const SDir *sdir, CPInfo *cpinfo, CPDD *cpdd)
+void check_overwrite(const OPArg *oparg, const SDir *sdir, CPInfo *cpinfo, CPDD *cpdd)
 {
 	if(info_flag == false)
 	{
@@ -751,7 +756,7 @@ struct stat * make_directory(CPInfo *cpinfo, CPDD *cpdd)
 #define TYPE_IS_LINK \
 {\
 	count_link_plus(cpinfo, cpdd);\
-	overwrite_check(oparg, sdir, cpinfo, cpdd);\
+	check_overwrite(oparg, sdir, cpinfo, cpdd);\
 	file_list = append_list(file_list, (void *)cpinfo);\
 }
 
@@ -759,7 +764,7 @@ struct stat * make_directory(CPInfo *cpinfo, CPDD *cpdd)
 {\
 	count_file_plus(cpinfo, cpdd);\
 	cpinfo->copy_mode = cpinfo_tmp->copy_mode;\
-	overwrite_check(oparg, sdir, cpinfo, cpdd);\
+	check_overwrite(oparg, sdir, cpinfo, cpdd);\
 	file_list = append_list(file_list, (void *)cpinfo);\
 }
 
