@@ -165,13 +165,20 @@ void compare_hash(const OPArg *oparg, const SDir *sdir, CPInfo *cpinfo, CPDD *cp
 			}
 			else
 			{
-				print_error("NODATA", __FILE__, __LINE__, cpdd);
 				fprintf(stderr, "ハッシュ値が一致しませんでした、%sを削除します\n", cpinfo->to);
+				print_error("NODATA", __FILE__, __LINE__, cpdd);
 				write_log_hash_check(cpinfo, ffrom, tto, sdir, cpdd, false);
-				unlink(cpinfo->to);
 				cpinfo->write = false;
-				/* falseで初期化しているので要らないはず */
-				/* cpinfo->hash_check = false; */
+
+				errno = 0;
+				if(unlink(cpinfo->to) == -1)
+				{
+					if(errno != ENOENT)
+					{
+						print_error("unlink", __FILE__, __LINE__, cpdd);
+						fprintf(stderr, "%s の削除に失敗しました\n", cpinfo->to);
+					}
+				}
 			}
 		}
 		else
