@@ -508,7 +508,7 @@ inline static void mw_small(CPInfo *cpinfo, CPDD *cpdd, md5_state_t *state, md5_
 
 	if(buf[0] == MAP_FAILED)
 	{
-		perror("mmap");
+		print_error("mmap", __FILE__, __LINE__, cpdd);
 	}
 	else
 	{
@@ -586,7 +586,7 @@ inline static void mw_big(CPInfo *cpinfo, CPDD *cpdd, md5_state_t *state, md5_by
 
 		if(buf[0] == MAP_FAILED)
 		{
-			perror("mmap");
+			print_error("mmap", __FILE__, __LINE__, cpdd);
 			break;
 		}
 		else
