@@ -162,7 +162,6 @@ void verify_hash(const OPArg *oparg, const SDir *sdir, CPInfo *cpinfo, CPDD *cpd
 
 				if(oparg->V == VERBOS)
 				{
-					puts("compare success");
 					printf("%s : %s\n", cpinfo->verify_md5, cpinfo->from);
 					printf("%s : %s\n", hex_output, cpinfo->to);
 					fflush(stdout);
@@ -179,7 +178,16 @@ void verify_hash(const OPArg *oparg, const SDir *sdir, CPInfo *cpinfo, CPDD *cpd
 				print_error("NODATA", __FILE__, __LINE__, cpdd);
 				write_log_hash_check(cpinfo, cpinfo->verify_md5, hex_output, sdir, cpdd, false);
 				cpinfo->write = false;
-				unlink(cpinfo->to);
+
+				errno = 0;
+				if(unlink(cpinfo->to) == -1)
+				{
+					if(errno != ENOENT)
+					{
+						print_error("unlink", __FILE__, __LINE__, cpdd);
+						fprintf(stderr, "%s の削除に失敗しました\n", cpinfo->to);
+					}
+				}
 			}
 			break;
 
